@@ -1,10 +1,6 @@
-/* -*- c-basic-offset: 2; indent-tabs-mode: nil -*- */
-#ifndef IFO_TYPES_H_INCLUDED
-#define IFO_TYPES_H_INCLUDED
-
-/*
- * Copyright (C) 2000, 2001 Bjrn Englund <d4bjorn@dtek.chalmers.se>,
- *                          Hkan Hjort <d95hjort@dtek.chalmers.se>
+/**
+ * Copyright (C) 2000 Bjrn Englund <d4bjorn@dtek.chalmers.se>,
+ *                    Hkan Hjort <d95hjort@dtek.chalmers.se>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,17 +17,12 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#ifndef IFO_TYPES_H_INCLUDED
+#define IFO_TYPES_H_INCLUDED
+
+#include <inttypes.h>
 #include <dvdread/dvd_reader.h>
 
-#if defined(__BEOS__)
-#if !defined(_INTTYPES_H_) && !defined(_INTTYPES_H) && !defined(_STDINT_H_) && !defined(_STDINT_H)
-#error "Must include <inttypes.h> or <stdint.h> before any libdvdread header."
-#endif
-#else
-#if !defined(UINT8_MAX) || !defined(UINT16_MAX) || !defined(INT32_MAX)
-#error "Must include <inttypes.h> or <stdint.h> before any libdvdread header."
-#endif
-#endif
 
 #undef ATTRIBUTE_PACKED
 #undef PRAGMA_PACK_BEGIN 
@@ -68,7 +59,7 @@ typedef struct {
   uint8_t hour;
   uint8_t minute;
   uint8_t second;
-  uint8_t frame_u; /* The two high bits are the frame rate. */
+  uint8_t frame_u; // The two high bits are the frame rate.
 } ATTRIBUTE_PACKED dvd_time_t;
 
 /**
@@ -77,7 +68,7 @@ typedef struct {
 typedef struct {
   uint8_t bytes[8];
 } ATTRIBUTE_PACKED vm_cmd_t;
-#define COMMAND_DATA_SIZE 8U
+#define COMMAND_DATA_SIZE 8
 
 
 /**
@@ -92,8 +83,7 @@ typedef struct {
   
   unsigned int line21_cc_1          : 1;
   unsigned int line21_cc_2          : 1;
-  unsigned int unknown1             : 1;
-  unsigned int bit_rate             : 1;
+  unsigned int unknown1             : 2;
   
   unsigned int picture_size         : 2;
   unsigned int letterboxed          : 1;
@@ -108,15 +98,14 @@ typedef struct {
   unsigned int letterboxed          : 1;
   unsigned int picture_size         : 2;
   
-  unsigned int bit_rate             : 1;
-  unsigned int unknown1             : 1;
+  unsigned int unknown1             : 2;
   unsigned int line21_cc_2          : 1;
   unsigned int line21_cc_1          : 1;
 #endif
 } ATTRIBUTE_PACKED video_attr_t;
 
 /**
- * Audio Attributes.
+ * Audio Attributes. (Incomplete/Wrong?)
  */
 typedef struct {
 #ifdef WORDS_BIGENDIAN
@@ -141,99 +130,13 @@ typedef struct {
   unsigned int quantization           : 2;
 #endif
   uint16_t lang_code;
+  uint8_t  lang_code2; // ??
   uint8_t  lang_extension;
-  uint8_t  code_extension;
-  uint8_t unknown3;
-  union {
-    struct {
-#ifdef WORDS_BIGENDIAN
-      unsigned int unknown4           : 1;
-      unsigned int channel_assignment : 3;
-      unsigned int version            : 2;
-      unsigned int mc_intro           : 1; /* probably 0: true, 1:false */
-      unsigned int mode               : 1; /* Karaoke mode 0: solo 1: duet */
-#else
-      unsigned int mode               : 1;
-      unsigned int mc_intro           : 1;
-      unsigned int version            : 2;
-      unsigned int channel_assignment : 3;
-      unsigned int unknown4           : 1;
-#endif
-    } ATTRIBUTE_PACKED karaoke;
-    struct {
-#ifdef WORDS_BIGENDIAN
-      unsigned int unknown5           : 4;
-      unsigned int dolby_encoded      : 1; /* suitable for surround decoding */
-      unsigned int unknown6           : 3;
-#else
-      unsigned int unknown6           : 3;
-      unsigned int dolby_encoded      : 1;
-      unsigned int unknown5           : 4;
-#endif
-    } ATTRIBUTE_PACKED surround;
-  } ATTRIBUTE_PACKED app_info;
+  uint16_t unknown2;
 } ATTRIBUTE_PACKED audio_attr_t;
 
-
 /**
- * MultiChannel Extension
- */
-typedef struct {
-#ifdef WORDS_BIGENDIAN
-  unsigned int zero1      : 7;
-  unsigned int ach0_gme   : 1;
-
-  unsigned int zero2      : 7;
-  unsigned int ach1_gme   : 1;
-
-  unsigned int zero3      : 4;
-  unsigned int ach2_gv1e  : 1;
-  unsigned int ach2_gv2e  : 1;
-  unsigned int ach2_gm1e  : 1;
-  unsigned int ach2_gm2e  : 1;
-
-  unsigned int zero4      : 4;
-  unsigned int ach3_gv1e  : 1;
-  unsigned int ach3_gv2e  : 1;
-  unsigned int ach3_gmAe  : 1;
-  unsigned int ach3_se2e  : 1;
-
-  unsigned int zero5      : 4;
-  unsigned int ach4_gv1e  : 1;
-  unsigned int ach4_gv2e  : 1;
-  unsigned int ach4_gmBe  : 1;
-  unsigned int ach4_seBe  : 1;
-#else
-  unsigned int ach0_gme   : 1;
-  unsigned int zero1      : 7;
-
-  unsigned int ach1_gme   : 1;
-  unsigned int zero2      : 7;
-
-  unsigned int ach2_gm2e  : 1;
-  unsigned int ach2_gm1e  : 1;
-  unsigned int ach2_gv2e  : 1;
-  unsigned int ach2_gv1e  : 1;
-  unsigned int zero3      : 4;
-
-  unsigned int ach3_se2e  : 1;
-  unsigned int ach3_gmAe  : 1;
-  unsigned int ach3_gv2e  : 1;
-  unsigned int ach3_gv1e  : 1;
-  unsigned int zero4      : 4;
-
-  unsigned int ach4_seBe  : 1;
-  unsigned int ach4_gmBe  : 1;
-  unsigned int ach4_gv2e  : 1;
-  unsigned int ach4_gv1e  : 1;
-  unsigned int zero5      : 4;
-#endif
-  uint8_t zero6[19];
-} ATTRIBUTE_PACKED multichannel_ext_t;
-
-
-/**
- * Subpicture Attributes.
+ * Subpicture Attributes.(Incomplete/Wrong)
  */
 typedef struct {
   /*
@@ -246,19 +149,11 @@ typedef struct {
    * language: indicates language if type == 1
    * lang extension: if type == 1 contains the lang extension
    */
-#ifdef WORDS_BIGENDIAN
-  unsigned int code_mode : 3;
-  unsigned int zero1     : 3;
-  unsigned int type      : 2;
-#else
-  unsigned int type      : 2;
-  unsigned int zero1     : 3;
-  unsigned int code_mode : 3;
-#endif
-  uint8_t  zero2;
+  uint8_t type;
+  uint8_t zero1;
   uint16_t lang_code;
-  uint8_t  lang_extension;
-  uint8_t  code_extension;
+  uint8_t lang_extension;
+  uint8_t zero2;
 } ATTRIBUTE_PACKED subp_attr_t;
 
 
@@ -270,12 +165,12 @@ typedef struct {
   uint16_t nr_of_pre;
   uint16_t nr_of_post;
   uint16_t nr_of_cell;
-  uint16_t last_byte;
+  uint16_t zero_1;
   vm_cmd_t *pre_cmds;
   vm_cmd_t *post_cmds;
   vm_cmd_t *cell_cmds;
 } ATTRIBUTE_PACKED pgc_command_tbl_t;
-#define PGC_COMMAND_TBL_SIZE 8U
+#define PGC_COMMAND_TBL_SIZE 8
 
 /**
  * PGC Program Map
@@ -294,8 +189,8 @@ typedef struct {
   unsigned int stc_discontinuity: 1;
   unsigned int seamless_angle   : 1;
   
-  unsigned int playback_mode    : 1;  /**< When set, enter StillMode after each VOBU */
-  unsigned int restricted       : 1;  /**< ?? drop out of fastforward? */
+  unsigned int unknown1         : 1;
+  unsigned int restricted       : 1;
   unsigned int unknown2         : 6;
 #else
   unsigned int seamless_angle   : 1;
@@ -307,7 +202,7 @@ typedef struct {
   
   unsigned int unknown2         : 6;
   unsigned int restricted       : 1;
-  unsigned int playback_mode    : 1;
+  unsigned int unknown1         : 1;
 #endif
   uint8_t still_time;
   uint8_t cell_cmd_nr;
@@ -340,65 +235,65 @@ typedef struct {
  */
 typedef struct {
 #ifdef WORDS_BIGENDIAN
-  unsigned int zero                           : 7; /* 25-31 */
-  unsigned int video_pres_mode_change         : 1; /* 24 */
+  unsigned int zero                           : 7; // 25-31
+  unsigned int video_pres_mode_change         : 1; // 24
   
-  unsigned int karaoke_audio_pres_mode_change : 1; /* 23 */
-  unsigned int angle_change                   : 1;
-  unsigned int subpic_stream_change           : 1;
-  unsigned int audio_stream_change            : 1;
-  unsigned int pause_on                       : 1;
-  unsigned int still_off                      : 1;
-  unsigned int button_select_or_activate      : 1;
-  unsigned int resume                         : 1; /* 16 */
+  unsigned int karaoke_audio_pres_mode_change : 1; // 23
+  unsigned int angle_change                   : 1; // 22
+  unsigned int subpic_stream_change           : 1; // 21
+  unsigned int audio_stream_change            : 1; // 20
+  unsigned int pause_on                       : 1; // 19
+  unsigned int still_off                      : 1; // 18
+  unsigned int button_select_or_activate      : 1; // 17
+  unsigned int resume                         : 1; // 16
   
-  unsigned int chapter_menu_call              : 1; /* 15 */
-  unsigned int angle_menu_call                : 1;
-  unsigned int audio_menu_call                : 1;
-  unsigned int subpic_menu_call               : 1;
-  unsigned int root_menu_call                 : 1;
-  unsigned int title_menu_call                : 1;
-  unsigned int backward_scan                  : 1;
-  unsigned int forward_scan                   : 1; /* 8 */
+  unsigned int chapter_menu_call              : 1; // 15
+  unsigned int angle_menu_call                : 1; // 14
+  unsigned int audio_menu_call                : 1; // 13
+  unsigned int subpic_menu_call               : 1; // 12
+  unsigned int root_menu_call                 : 1; // 11
+  unsigned int title_menu_call                : 1; // 10
+  unsigned int backward_scan                  : 1; // 9
+  unsigned int forward_scan                   : 1; // 8
   
-  unsigned int next_pg_search                 : 1; /* 7 */
-  unsigned int prev_or_top_pg_search          : 1;
-  unsigned int time_or_chapter_search         : 1;
-  unsigned int go_up                          : 1;
-  unsigned int stop                           : 1;
-  unsigned int title_play                     : 1;
-  unsigned int chapter_search_or_play         : 1;
-  unsigned int title_or_time_play             : 1; /* 0 */
+  unsigned int next_pg_search                 : 1; // 7
+  unsigned int prev_or_top_pg_search          : 1; // 6
+  unsigned int time_or_chapter_search         : 1; // 5
+  unsigned int go_up                          : 1; // 4
+  unsigned int stop                           : 1; // 3
+  unsigned int title_play                     : 1; // 2
+  unsigned int chapter_search_or_play         : 1; // 1
+  unsigned int title_or_time_play             : 1; // 0
 #else
-  unsigned int video_pres_mode_change         : 1; /* 24 */
-  unsigned int zero                           : 7; /* 25-31 */
+  unsigned int video_pres_mode_change         : 1; // 24
+  unsigned int zero                           : 7; // 25-31
   
-  unsigned int resume                         : 1; /* 16 */
-  unsigned int button_select_or_activate      : 1;
-  unsigned int still_off                      : 1;
-  unsigned int pause_on                       : 1;
-  unsigned int audio_stream_change            : 1;
-  unsigned int subpic_stream_change           : 1;
-  unsigned int angle_change                   : 1;
-  unsigned int karaoke_audio_pres_mode_change : 1; /* 23 */
+  unsigned int resume                         : 1; // 16
+  unsigned int button_select_or_activate      : 1; // 17
+  unsigned int still_off                      : 1; // 18
+  unsigned int pause_on                       : 1; // 19
+  unsigned int audio_stream_change            : 1; // 20
+  unsigned int subpic_stream_change           : 1; // 21
+  unsigned int angle_change                   : 1; // 22
+  unsigned int karaoke_audio_pres_mode_change : 1; // 23
   
-  unsigned int forward_scan                   : 1; /* 8 */
-  unsigned int backward_scan                  : 1;
-  unsigned int title_menu_call                : 1;
-  unsigned int root_menu_call                 : 1;
-  unsigned int subpic_menu_call               : 1;
-  unsigned int audio_menu_call                : 1;
-  unsigned int angle_menu_call                : 1;
-  unsigned int chapter_menu_call              : 1; /* 15 */
+  unsigned int forward_scan                   : 1; // 8
+  unsigned int backward_scan                  : 1; // 9
+  unsigned int title_menu_call                : 1; // 10
+  unsigned int root_menu_call                 : 1; // 11
+  unsigned int subpic_menu_call               : 1; // 12
+  unsigned int audio_menu_call                : 1; // 13
+  unsigned int angle_menu_call                : 1; // 14
+  unsigned int chapter_menu_call              : 1; // 15
   
-  unsigned int title_or_time_play             : 1; /* 0 */
-  unsigned int chapter_search_or_play         : 1;
-  unsigned int title_play                     : 1;
-  unsigned int stop                           : 1;
-  unsigned int go_up                          : 1;
-  unsigned int time_or_chapter_search         : 1;
-  unsigned int prev_or_top_pg_search          : 1;
-  unsigned int next_pg_search                 : 1; /* 7 */
+  unsigned int title_or_time_play             : 1; // 0
+  unsigned int chapter_search_or_play         : 1; // 1
+  unsigned int title_play                     : 1; // 2
+  unsigned int stop                           : 1; // 3
+  unsigned int go_up                          : 1; // 4
+  unsigned int time_or_chapter_search         : 1; // 5
+  unsigned int prev_or_top_pg_search          : 1; // 6
+  unsigned int next_pg_search                 : 1; // 7
 #endif
 } ATTRIBUTE_PACKED user_ops_t;
 
@@ -416,8 +311,8 @@ typedef struct {
   uint16_t next_pgc_nr;
   uint16_t prev_pgc_nr;
   uint16_t goup_pgc_nr;
-  uint8_t  pg_playback_mode;
   uint8_t  still_time;
+  uint8_t  pg_playback_mode;
   uint32_t palette[16]; /* New type struct {zero_1, Y, Cr, Cb} ? */
   uint16_t command_tbl_offset;
   uint16_t program_map_offset;
@@ -428,7 +323,7 @@ typedef struct {
   cell_playback_t *cell_playback;
   cell_position_t *cell_position;
 } ATTRIBUTE_PACKED pgc_t;
-#define PGC_SIZE 236U
+#define PGC_SIZE 236
 
 /**
  * Program Chain Information Search Pointer.
@@ -448,7 +343,7 @@ typedef struct {
   uint32_t pgc_start_byte;
   pgc_t *pgc;
 } ATTRIBUTE_PACKED pgci_srp_t;
-#define PGCI_SRP_SIZE 8U
+#define PGCI_SRP_SIZE 8
 
 /**
  * Program Chain Information Table.
@@ -459,19 +354,19 @@ typedef struct {
   uint32_t last_byte;
   pgci_srp_t *pgci_srp;
 } ATTRIBUTE_PACKED pgcit_t;
-#define PGCIT_SIZE 8U
+#define PGCIT_SIZE 8
 
 /**
  * Menu PGCI Language Unit.
  */
 typedef struct {
   uint16_t lang_code;
-  uint8_t  lang_extension;
+  uint8_t  zero_1;
   uint8_t  exists;
   uint32_t lang_start_byte;
   pgcit_t *pgcit;
 } ATTRIBUTE_PACKED pgci_lu_t;
-#define PGCI_LU_SIZE 8U
+#define PGCI_LU_SIZE 8
 
 /**
  * Menu PGCI Unit Table.
@@ -482,7 +377,7 @@ typedef struct {
   uint32_t last_byte;
   pgci_lu_t *lu;
 } ATTRIBUTE_PACKED pgci_ut_t;
-#define PGCI_UT_SIZE 8U
+#define PGCI_UT_SIZE 8
 
 /**
  * Cell Address Information.
@@ -502,9 +397,9 @@ typedef struct {
   uint16_t nr_of_vobs; /* VOBs */
   uint16_t zero_1;
   uint32_t last_byte;
-  cell_adr_t *cell_adr_table;  /* No explicit size given. */
+  cell_adr_t *cell_adr_table;
 } ATTRIBUTE_PACKED c_adt_t;
-#define C_ADT_SIZE 8U
+#define C_ADT_SIZE 8
 
 /**
  * VOBU Address Map.
@@ -513,7 +408,7 @@ typedef struct {
   uint32_t last_byte;
   uint32_t *vobu_start_sectors;
 } ATTRIBUTE_PACKED vobu_admap_t;
-#define VOBU_ADMAP_SIZE 4U
+#define VOBU_ADMAP_SIZE 4
 
 
 
@@ -558,11 +453,11 @@ typedef struct {
   
   video_attr_t vmgm_video_attr;
   uint8_t  zero_7;
-  uint8_t  nr_of_vmgm_audio_streams; /* should be 0 or 1 */
+  uint8_t  nr_of_vmgm_audio_streams; // should be 0 or 1
   audio_attr_t vmgm_audio_attr;
   audio_attr_t zero_8[7];
   uint8_t  zero_9[17];
-  uint8_t  nr_of_vmgm_subp_streams; /* should be 0 or 1 */
+  uint8_t  nr_of_vmgm_subp_streams; // should be 0 or 1
   subp_attr_t  vmgm_subp_attr;
   subp_attr_t  zero_10[27];  /* XXX: how much 'padding' here? */
 } ATTRIBUTE_PACKED vmgi_mat_t;
@@ -570,21 +465,21 @@ typedef struct {
 typedef struct {
 #ifdef WORDS_BIGENDIAN
   unsigned int zero_1                    : 1;
-  unsigned int multi_or_random_pgc_title : 1; /* 0: one sequential pgc title */
+  unsigned int multi_or_random_pgc_title : 1; // 0 == one sequential pgc title
   unsigned int jlc_exists_in_cell_cmd    : 1;
   unsigned int jlc_exists_in_prepost_cmd : 1;
   unsigned int jlc_exists_in_button_cmd  : 1;
   unsigned int jlc_exists_in_tt_dom      : 1;
-  unsigned int chapter_search_or_play    : 1; /* UOP 1 */
-  unsigned int title_or_time_play        : 1; /* UOP 0 */
+  unsigned int chapter_search_or_play    : 1; // UOP 1
+  unsigned int title_or_time_play        : 1; // UOP 0
 #else
-  unsigned int title_or_time_play        : 1;
-  unsigned int chapter_search_or_play    : 1;
+  unsigned int title_or_time_play        : 1; // UOP 0
+  unsigned int chapter_search_or_play    : 1; // UOP 1
   unsigned int jlc_exists_in_tt_dom      : 1;
   unsigned int jlc_exists_in_button_cmd  : 1;
   unsigned int jlc_exists_in_prepost_cmd : 1;
   unsigned int jlc_exists_in_cell_cmd    : 1;
-  unsigned int multi_or_random_pgc_title : 1;
+  unsigned int multi_or_random_pgc_title : 1; // 0 == one sequential pgc title
   unsigned int zero_1                    : 1;
 #endif
 } ATTRIBUTE_PACKED playback_type_t;
@@ -611,14 +506,7 @@ typedef struct {
   uint32_t last_byte;
   title_info_t *title;
 } ATTRIBUTE_PACKED tt_srpt_t;
-#define TT_SRPT_SIZE 8U
-
-
-/**
- * Parental Management Information Unit Table.
- * Level 1 (US: G), ..., 7 (US: NC-17), 8
- */
-typedef uint16_t pf_level_t[8];
+#define TT_SRPT_SIZE 8
 
 /**
  * Parental Management Information Unit Table.
@@ -628,9 +516,9 @@ typedef struct {
   uint16_t zero_1;
   uint16_t pf_ptl_mai_start_byte;
   uint16_t zero_2;
-  pf_level_t *pf_ptl_mai; /* table of (nr_of_vtss + 1), video_ts is first */
+  /* uint16_t *pf_ptl_mai // table of nr_of_vtss+1 x 8 */
 } ATTRIBUTE_PACKED ptl_mait_country_t;
-#define PTL_MAIT_COUNTRY_SIZE 8U
+#define PTL_MAIT_COUNTRY_SIZE 8
 
 /**
  * Parental Management Information Table.
@@ -641,7 +529,7 @@ typedef struct {
   uint32_t last_byte;
   ptl_mait_country_t *countries;
 } ATTRIBUTE_PACKED ptl_mait_t;
-#define PTL_MAIT_SIZE 8U
+#define PTL_MAIT_SIZE 8
 
 /**
  * Video Title Set Attributes.
@@ -652,12 +540,12 @@ typedef struct {
   
   video_attr_t vtsm_vobs_attr;
   uint8_t  zero_1;
-  uint8_t  nr_of_vtsm_audio_streams; /* should be 0 or 1 */
+  uint8_t  nr_of_vtsm_audio_streams; // should be 0 or 1
   audio_attr_t vtsm_audio_attr;
   audio_attr_t zero_2[7];  
   uint8_t  zero_3[16];
   uint8_t  zero_4;
-  uint8_t  nr_of_vtsm_subp_streams; /* should be 0 or 1 */
+  uint8_t  nr_of_vtsm_subp_streams; // should be 0 or 1
   subp_attr_t vtsm_subp_attr;
   subp_attr_t zero_5[27];
   
@@ -672,8 +560,8 @@ typedef struct {
   uint8_t  nr_of_vtstt_subp_streams;
   subp_attr_t vtstt_subp_attr[32];
 } ATTRIBUTE_PACKED vts_attributes_t;
-#define VTS_ATTRIBUTES_SIZE 542U
-#define VTS_ATTRIBUTES_MIN_SIZE 356U
+#define VTS_ATTRIBUTES_SIZE 542
+#define VTS_ATTRIBUTES_MIN_SIZE 356
 
 /**
  * Video Title Set Attribute Table.
@@ -683,9 +571,8 @@ typedef struct {
   uint16_t zero_1;
   uint32_t last_byte;
   vts_attributes_t *vts;
-  uint32_t *vts_atrt_offsets; /* offsets table for each vts_attributes */
 } ATTRIBUTE_PACKED vts_atrt_t;
-#define VTS_ATRT_SIZE 8U
+#define VTS_ATRT_SIZE 8
 
 /**
  * Text Data. (Incomplete)
@@ -694,18 +581,18 @@ typedef struct {
   uint32_t last_byte;    /* offsets are relative here */
   uint16_t offsets[100]; /* == nr_of_srpts + 1 (first is disc title) */
 #if 0  
-  uint16_t unknown; /* 0x48 ?? 0x48 words (16bit) info following */
+  uint16_t unknown; // 0x48 ?? 0x48 words (16bit) info following
   uint16_t zero_1;
   
-  uint8_t type_of_info; /* ?? 01 == disc, 02 == Title, 04 == Title part */
+  uint8_t type_of_info;//?? 01 == disc, 02 == Title, 04 == Title part 
   uint8_t unknown1;
   uint8_t unknown2;
   uint8_t unknown3;
-  uint8_t unknown4; /* ?? allways 0x30 language?, text format? */
+  uint8_t unknown4;//?? allways 0x30 language?, text format?
   uint8_t unknown5;
-  uint16_t offset; /* from first */
+  uint16_t offset; // from first 
   
-  char text[12]; /* ended by 0x09 */
+  char text[12]; // ended by 0x09
 #endif
 } ATTRIBUTE_PACKED txtdt_t;
 
@@ -718,7 +605,7 @@ typedef struct {
   uint32_t txtdt_start_byte;  /* prt, rel start of vmg_txtdt_mgi  */
   txtdt_t  *txtdt;
 } ATTRIBUTE_PACKED txtdt_lu_t;
-#define TXTDT_LU_SIZE 8U
+#define TXTDT_LU_SIZE 8
 
 /**
  * Text Data Manager Information. (Incomplete)
@@ -729,7 +616,7 @@ typedef struct {
   uint32_t last_byte;
   txtdt_lu_t *lu;
 } ATTRIBUTE_PACKED txtdt_mgi_t;
-#define TXTDT_MGI_SIZE 20U
+#define TXTDT_MGI_SIZE 20
 
 
 /**
@@ -765,7 +652,7 @@ typedef struct {
   uint32_t vts_ptt_srpt;    /* sector */
   uint32_t vts_pgcit;       /* sector */
   uint32_t vtsm_pgci_ut;    /* sector */
-  uint32_t vts_tmapt;       /* sector */
+  uint32_t vts_tmapt;       /* sector */  // XXX: FIXME TODO Implement
   uint32_t vtsm_c_adt;      /* sector */
   uint32_t vtsm_vobu_admap; /* sector */
   uint32_t vts_c_adt;       /* sector */
@@ -774,11 +661,11 @@ typedef struct {
   
   video_attr_t vtsm_video_attr;
   uint8_t  zero_14;
-  uint8_t  nr_of_vtsm_audio_streams; /* should be 0 or 1 */
+  uint8_t  nr_of_vtsm_audio_streams; // should be 0 or 1
   audio_attr_t vtsm_audio_attr;
   audio_attr_t zero_15[7];
   uint8_t  zero_16[17];
-  uint8_t  nr_of_vtsm_subp_streams; /* should be 0 or 1 */
+  uint8_t  nr_of_vtsm_subp_streams; // should be 0 or 1
   subp_attr_t vtsm_subp_attr;
   subp_attr_t zero_17[27];
   uint8_t  zero_18[2];
@@ -790,8 +677,6 @@ typedef struct {
   uint8_t  zero_20[17];
   uint8_t  nr_of_vts_subp_streams;
   subp_attr_t vts_subp_attr[32];
-  uint16_t zero_21;
-  multichannel_ext_t vts_mu_audio_attr[8];
   /* XXX: how much 'padding' here, if any? */
 } ATTRIBUTE_PACKED vtsi_mat_t;
 
@@ -819,39 +704,8 @@ typedef struct {
   uint16_t zero_1;
   uint32_t last_byte;
   ttu_t  *title;
-  uint32_t *ttu_offset; /* offset table for each ttu */
 } ATTRIBUTE_PACKED vts_ptt_srpt_t;
-#define VTS_PTT_SRPT_SIZE 8U
-
-
-/**
- * Time Map Entry.
- */
-/* Should this be bit field at all or just the uint32_t? */
-typedef uint32_t map_ent_t;
-
-/**
- * Time Map.
- */
-typedef struct {
-  uint8_t  tmu;   /* Time unit, in seconds */
-  uint8_t  zero_1;
-  uint16_t nr_of_entries;
-  map_ent_t *map_ent;
-} ATTRIBUTE_PACKED vts_tmap_t;
-#define VTS_TMAP_SIZE 4U
-
-/**
- * Time Map Table.
- */
-typedef struct {
-  uint16_t nr_of_tmaps;
-  uint16_t zero_1;
-  uint32_t last_byte;
-  vts_tmap_t *tmap;
-  uint32_t *tmap_offset; /* offset table for each tmap */
-} ATTRIBUTE_PACKED vts_tmapt_t;
-#define VTS_TMAPT_SIZE 8U
+#define VTS_PTT_SRPT_SIZE 8
 
 
 #if PRAGMA_PACK
@@ -885,7 +739,7 @@ typedef struct {
   vtsi_mat_t     *vtsi_mat;
   vts_ptt_srpt_t *vts_ptt_srpt;
   pgcit_t        *vts_pgcit;
-  vts_tmapt_t    *vts_tmapt;
+  int            *vts_tmapt; // FIXME add/correct the type
   c_adt_t        *vts_c_adt;
   vobu_admap_t   *vts_vobu_admap;
 } ifo_handle_t;
