@@ -1,7 +1,4 @@
-#ifndef NAV_PRINT_H_INCLUDED
-#define NAV_PRINT_H_INCLUDED
-
-/*
+/**
  * Copyright (C) 2001 Billy Biggs <vektor@dumbterm.net>,
  *                    Hkan Hjort <d95hjort@dtek.chalmers.se>
  *
@@ -17,9 +14,13 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#ifndef NAV_PRINT_H_INCLUDED
+#define NAV_PRINT_H_INCLUDED
+
+#include <stdio.h>
 #include <dvdread/nav_types.h>
 
 #ifdef __cplusplus
@@ -27,14 +28,12 @@ extern "C" {
 #endif
 
 /**
- * Prints information contained in the PCI to stdout.
+ * This file provides example functions for printing information about the NAV
+ * packet to stdout.
  */
-void navPrint_PCI(pci_t *);
-  
-/**
- * Prints information contained in the DSI to stdout.
- */
-void navPrint_DSI(dsi_t *);
+
+void navPrint_PCI(pci_t *pci);
+void navPrint_DSI(dsi_t *dsi);
 
 #ifdef __cplusplus
 };
