@@ -1,9 +1,5 @@
-/* -*- c-basic-offset: 2; indent-tabs-mode: nil -*- */
-#ifndef NAV_READ_H_INCLUDED
-#define NAV_READ_H_INCLUDED
-
-/*
- * Copyright (C) 2000, 2001, 2002 Hkan Hjort <d95hjort@dtek.chalmers.se>.
+/**
+ * Copyright (C) 2000, 2001 Hkan Hjort <d95hjort@dtek.chalmers.se>.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,31 +16,24 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <dvdread/nav_types.h>
+#ifndef NAV_READ_H_INCLUDED
+#define NAV_READ_H_INCLUDED
 
-/**
- * Parsing of NAV data, PCI and DSI parts.
- */
+#include <dvdread/nav_types.h>
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
 /**
- * Reads the PCI packet data pointed to into th pci struct.
- * 
- * @param pci Pointer to the PCI data structure to be filled in.
- * @param bufffer Pointer to the buffer of the on disc PCI data.
- */  
-void navRead_PCI(pci_t *, unsigned char *);
+ * Reads the PCI packet which begins at buffer into pci.
+ */
+void navRead_PCI(pci_t *pci, unsigned char *buffer);
 
 /**
- * Reads the DSI packet data pointed to into dsi struct.
- * 
- * @param dsi Pointer to the DSI data structure to be filled in.
- * @param bufffer Pointer to the buffer of the on disc DSI data.
+ * Reads the DSI packet which begins at buffer into dsi.
  */
-void navRead_DSI(dsi_t *, unsigned char *);
+void navRead_DSI(dsi_t *dsi, unsigned char *buffer);
 
 #ifdef __cplusplus
 };
