@@ -1,4 +1,4 @@
-/*
+/**
  * Copyright (C) 2001 Billy Biggs <vektor@dumbterm.net>.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,6 +20,8 @@
 #include <stdlib.h>
 #include <assert.h>
 
+#include "config.h"
+
 #include <dvdread/dvd_reader.h>
 #include <dvdread/ifo_types.h>
 #include <dvdread/ifo_read.h>
